searchNodes=[{"doc":"Library for dealing with descision theory algorithms.","ref":"Descisionex.html","title":"Descisionex","type":"module"},{"doc":"","ref":"Descisionex.html#analytic_hierarchy/0","title":"Descisionex.analytic_hierarchy/0","type":"function"},{"doc":"","ref":"Descisionex.html#analytic_hierarchy/1","title":"Descisionex.analytic_hierarchy/1","type":"function"},{"doc":"","ref":"Descisionex.html#payment_matrix/0","title":"Descisionex.payment_matrix/0","type":"function"},{"doc":"","ref":"Descisionex.html#payment_matrix/1","title":"Descisionex.payment_matrix/1","type":"function"},{"doc":"","ref":"Descisionex.html#set_alternatives/2","title":"Descisionex.set_alternatives/2","type":"function"},{"doc":"","ref":"Descisionex.html#set_alternatives_matrix/2","title":"Descisionex.set_alternatives_matrix/2","type":"function"},{"doc":"","ref":"Descisionex.html#set_criteria/2","title":"Descisionex.set_criteria/2","type":"function"},{"doc":"https://en.wikipedia.org/wiki/Analytic_hierarchy_process","ref":"Descisionex.AnalyticHierarchy.html","title":"Descisionex.AnalyticHierarchy","type":"module"},{"doc":"Calculates alternatives weights for analytic hierarchy (criteria must be set, such as comparison matrix and weights before must be calculated!). Examples iex&gt; % Descisionex.AnalyticHierarchy { comparison_matrix : [ [ 1 , 2 ] , [ 3 , 4 ] ] } |&gt; Descisionex.AnalyticHierarchy . set_criteria ( [ &quot;some&quot; , &quot;criteria&quot; ] ) |&gt; Descisionex.AnalyticHierarchy . normalize_comparison_matrix ( ) |&gt; Descisionex.AnalyticHierarchy . set_alternatives ( [ &quot;some&quot; , &quot;alternatives&quot; ] ) |&gt; Descisionex.AnalyticHierarchy . set_alternatives_matrix ( [ [ [ 1 , 2 , 3 ] ] , [ [ 4 , 5 , 6 ] ] ] ) |&gt; Descisionex.AnalyticHierarchy . calculate_alternatives_weights_by_criteria ( ) |&gt; Descisionex.AnalyticHierarchy . calculate_alternatives_weights ( ) ** (ArgumentError) Weights must be calculated before! iex&gt; % Descisionex.AnalyticHierarchy { comparison_matrix : [ [ 1 , 2 ] , [ 3 , 4 ] ] } |&gt; Descisionex.AnalyticHierarchy . set_criteria ( [ &quot;some&quot; , &quot;criteria&quot; ] ) |&gt; Descisionex.AnalyticHierarchy . normalize_comparison_matrix ( ) |&gt; Descisionex.AnalyticHierarchy . calculate_criteria_weights ( ) |&gt; Descisionex.AnalyticHierarchy . set_alternatives ( [ &quot;some&quot; , &quot;alternatives&quot; ] ) |&gt; Descisionex.AnalyticHierarchy . set_alternatives_matrix ( [ [ [ 1 , 2 , 3 ] ] , [ [ 4 , 5 , 6 ] ] ] ) |&gt; Descisionex.AnalyticHierarchy . calculate_alternatives_weights_by_criteria ( ) |&gt; Descisionex.AnalyticHierarchy . calculate_alternatives_weights ( ) % Descisionex.AnalyticHierarchy { alternatives : [ &quot;some&quot; , &quot;alternatives&quot; ] , alternatives_matrix : %{ &quot;criteria&quot; =&gt; [ [ 4 , 5 , 6 ] ] , &quot;some&quot; =&gt; [ [ 1 , 2 , 3 ] ] } , alternatives_num : 2 , alternatives_weights : [ 3.0 ] , alternatives_weights_by_criteria : [ [ 3.0 , 3.0 ] ] , comparison_matrix : [ [ 1 , 2 ] , [ 3 , 4 ] ] , criteria : [ &quot;some&quot; , &quot;criteria&quot; ] , criteria_num : 2 , criteria_weights : [ [ 0.291 ] , [ 0.709 ] ] , normalized_comparison_matrix : [ [ 0.25 , 0.333 ] , [ 0.75 , 0.667 ] ] }","ref":"Descisionex.AnalyticHierarchy.html#calculate_alternatives_weights/1","title":"Descisionex.AnalyticHierarchy.calculate_alternatives_weights/1","type":"function"},{"doc":"Calculates alternatives weights by criteria for analytic hierarchy (criteria must be set, such as comparison matrix!). Examples iex&gt; % Descisionex.AnalyticHierarchy { comparison_matrix : [ [ 1 , 2 ] , [ 3 , 4 ] ] } |&gt; Descisionex.AnalyticHierarchy . set_criteria ( [ &quot;some&quot; , &quot;criteria&quot; ] ) |&gt; Descisionex.AnalyticHierarchy . calculate_alternatives_weights_by_criteria ( ) ** (ArgumentError) Alternatives matrix must be set! iex&gt; % Descisionex.AnalyticHierarchy { } |&gt; Descisionex.AnalyticHierarchy . set_criteria ( [ &quot;some&quot; , &quot;criteria&quot; ] ) |&gt; Descisionex.AnalyticHierarchy . set_alternatives ( [ &quot;some&quot; , &quot;alternatives&quot; ] ) |&gt; Descisionex.AnalyticHierarchy . set_alternatives_matrix ( [ [ [ 1 , 2 , 3 ] ] , [ [ 4 , 5 , 6 ] ] ] ) |&gt; Descisionex.AnalyticHierarchy . calculate_alternatives_weights_by_criteria ( ) % Descisionex.AnalyticHierarchy { alternatives : [ &quot;some&quot; , &quot;alternatives&quot; ] , alternatives_matrix : %{ &quot;criteria&quot; =&gt; [ [ 4 , 5 , 6 ] ] , &quot;some&quot; =&gt; [ [ 1 , 2 , 3 ] ] } , alternatives_num : 2 , alternatives_weights : [ ] , alternatives_weights_by_criteria : [ [ 3.0 , 3.0 ] ] , comparison_matrix : [ ] , criteria : [ &quot;some&quot; , &quot;criteria&quot; ] , criteria_num : 2 , criteria_weights : [ ] , normalized_comparison_matrix : [ ] }","ref":"Descisionex.AnalyticHierarchy.html#calculate_alternatives_weights_by_criteria/1","title":"Descisionex.AnalyticHierarchy.calculate_alternatives_weights_by_criteria/1","type":"function"},{"doc":"Calculates weights for normalized comparison matrix for analytic hierarchy (criteria must be set, such as comparison matrix!). Examples iex&gt; % Descisionex.AnalyticHierarchy { comparison_matrix : [ [ 1 , 2 ] , [ 3 , 4 ] ] } |&gt; Descisionex.AnalyticHierarchy . set_criteria ( [ &quot;some&quot; , &quot;criteria&quot; ] ) |&gt; Descisionex.AnalyticHierarchy . calculate_criteria_weights ( ) ** (ArgumentError) Comparison matrix must be normalized! iex&gt; % Descisionex.AnalyticHierarchy { comparison_matrix : [ [ 1 , 2 ] , [ 3 , 4 ] ] } |&gt; Descisionex.AnalyticHierarchy . set_criteria ( [ &quot;some&quot; , &quot;criteria&quot; ] ) |&gt; Descisionex.AnalyticHierarchy . normalize_comparison_matrix ( ) |&gt; Descisionex.AnalyticHierarchy . calculate_criteria_weights ( ) % Descisionex.AnalyticHierarchy { alternatives : [ ] , alternatives_matrix : %{ } , alternatives_num : 0 , alternatives_weights : [ ] , alternatives_weights_by_criteria : [ ] , comparison_matrix : [ [ 1 , 2 ] , [ 3 , 4 ] ] , criteria : [ &quot;some&quot; , &quot;criteria&quot; ] , criteria_num : 2 , criteria_weights : [ [ 0.291 ] , [ 0.709 ] ] , normalized_comparison_matrix : [ [ 0.25 , 0.333 ] , [ 0.75 , 0.667 ] ] }","ref":"Descisionex.AnalyticHierarchy.html#calculate_criteria_weights/1","title":"Descisionex.AnalyticHierarchy.calculate_criteria_weights/1","type":"function"},{"doc":"Normalizes comparison matrix for analytic hierarchy (criteria must be set, such as comparison matrix!). Examples iex&gt; % Descisionex.AnalyticHierarchy { } |&gt; Descisionex.AnalyticHierarchy . set_criteria ( [ &quot;some&quot; , &quot;criteria&quot; ] ) |&gt; Descisionex.AnalyticHierarchy . normalize_comparison_matrix ( ) ** (ArgumentError) Comparison matrix must be set! iex&gt; % Descisionex.AnalyticHierarchy { comparison_matrix : [ [ 1 , 2 ] , [ 3 , 4 ] ] } |&gt; Descisionex.AnalyticHierarchy . set_criteria ( [ &quot;some&quot; , &quot;criteria&quot; ] ) |&gt; Descisionex.AnalyticHierarchy . normalize_comparison_matrix ( ) % Descisionex.AnalyticHierarchy { alternatives : [ ] , alternatives_matrix : %{ } , alternatives_num : 0 , alternatives_weights : [ ] , alternatives_weights_by_criteria : [ ] , comparison_matrix : [ [ 1 , 2 ] , [ 3 , 4 ] ] , criteria : [ &quot;some&quot; , &quot;criteria&quot; ] , criteria_num : 2 , criteria_weights : [ ] , normalized_comparison_matrix : [ [ 0.25 , 0.333 ] , [ 0.75 , 0.667 ] ] }","ref":"Descisionex.AnalyticHierarchy.html#normalize_comparison_matrix/1","title":"Descisionex.AnalyticHierarchy.normalize_comparison_matrix/1","type":"function"},{"doc":"Set alternatives for analytic hierarchy. Examples iex&gt; % Descisionex.AnalyticHierarchy { } |&gt; Descisionex.AnalyticHierarchy . set_alternatives ( [ ] ) ** (ArgumentError) Alternatives must be not empty! iex&gt; % Descisionex.AnalyticHierarchy { } |&gt; Descisionex.AnalyticHierarchy . set_alternatives ( [ &quot;some&quot; , &quot;alternatives&quot; ] ) % Descisionex.AnalyticHierarchy { alternatives : [ &quot;some&quot; , &quot;alternatives&quot; ] , alternatives_matrix : %{ } , alternatives_num : 2 , alternatives_weights : [ ] , alternatives_weights_by_criteria : [ ] , comparison_matrix : [ ] , criteria : [ ] , criteria_num : 0 , criteria_weights : [ ] , normalized_comparison_matrix : [ ] }","ref":"Descisionex.AnalyticHierarchy.html#set_alternatives/2","title":"Descisionex.AnalyticHierarchy.set_alternatives/2","type":"function"},{"doc":"Set alternatives matrix for analytic hierarchy (criteria must be set!). Examples iex&gt; % Descisionex.AnalyticHierarchy { } |&gt; Descisionex.AnalyticHierarchy . set_alternatives_matrix ( [ [ 1 , 2 ] , [ 3 , 4 ] ] ) ** (ArgumentError) Criteria must be set! iex&gt; % Descisionex.AnalyticHierarchy { } |&gt; Descisionex.AnalyticHierarchy . set_criteria ( [ &quot;some&quot; , &quot;criteria&quot; ] ) |&gt; Descisionex.AnalyticHierarchy . set_alternatives_matrix ( [ [ 1 , 2 ] , [ 3 , 4 ] ] ) % Descisionex.AnalyticHierarchy { alternatives : [ ] , alternatives_matrix : %{ &quot;criteria&quot; =&gt; [ 3 , 4 ] , &quot;some&quot; =&gt; [ 1 , 2 ] } , alternatives_num : 0 , alternatives_weights : [ ] , alternatives_weights_by_criteria : [ ] , comparison_matrix : [ ] , criteria : [ &quot;some&quot; , &quot;criteria&quot; ] , criteria_num : 2 , criteria_weights : [ ] , normalized_comparison_matrix : [ ] }","ref":"Descisionex.AnalyticHierarchy.html#set_alternatives_matrix/2","title":"Descisionex.AnalyticHierarchy.set_alternatives_matrix/2","type":"function"},{"doc":"Set criteria for analytic hierarchy. Examples iex&gt; % Descisionex.AnalyticHierarchy { } |&gt; Descisionex.AnalyticHierarchy . set_criteria ( [ ] ) ** (ArgumentError) Criteria must be not empty! iex&gt; % Descisionex.AnalyticHierarchy { } |&gt; Descisionex.AnalyticHierarchy . set_criteria ( [ &quot;some&quot; , &quot;criteria&quot; ] ) % Descisionex.AnalyticHierarchy { alternatives : [ ] , alternatives_matrix : %{ } , alternatives_num : 0 , alternatives_weights : [ ] , alternatives_weights_by_criteria : [ ] , comparison_matrix : [ ] , criteria : [ &quot;some&quot; , &quot;criteria&quot; ] , criteria_num : 2 , criteria_weights : [ ] , normalized_comparison_matrix : [ ] }","ref":"Descisionex.AnalyticHierarchy.html#set_criteria/2","title":"Descisionex.AnalyticHierarchy.set_criteria/2","type":"function"},{"doc":"","ref":"Descisionex.AnalyticHierarchy.html#set_tagged_alternatives_matrix/2","title":"Descisionex.AnalyticHierarchy.set_tagged_alternatives_matrix/2","type":"function"},{"doc":"Utility functions","ref":"Descisionex.Helper.html","title":"Descisionex.Helper","type":"module"},{"doc":"Average number for matrix row. Examples iex&gt; matrix = [ [ 1 , 2 ] , [ 3 , 4 ] , [ 0 , 1 ] ] iex&gt; Enum . map ( matrix , fn row -&gt; Descisionex.Helper . avg ( row , 2 ) end ) [ 1.5 , 3.5 , 0.5 ]","ref":"Descisionex.Helper.html#avg/2","title":"Descisionex.Helper.avg/2","type":"function"},{"doc":"Calculate weights for matrix rows. Examples iex&gt; matrix = [ [ 1 , 2 ] , [ 3 , 4 ] , [ 0 , 1 ] ] iex&gt; size = 2 # matrix row elements count iex&gt; Descisionex.Helper . calculate_weights ( matrix , size ) [ [ 1.5 ] , [ 3.5 ] , [ 0.5 ] ]","ref":"Descisionex.Helper.html#calculate_weights/2","title":"Descisionex.Helper.calculate_weights/2","type":"function"},{"doc":"Find maximal criteria (row) in matrix (with index). Examples iex&gt; matrix = [ [ 1 , 2 ] , [ 3 , 4 ] , [ 0 , 1 ] ] iex&gt; Descisionex.Helper . find_max_criteria ( matrix ) { [ 3 , 4 ] , 1 }","ref":"Descisionex.Helper.html#find_max_criteria/1","title":"Descisionex.Helper.find_max_criteria/1","type":"function"},{"doc":"Find minimal criteria (row) in matrix (with index). Examples iex&gt; matrix = [ [ 1 , 2 ] , [ 3 , 4 ] , [ 0 , 1 ] ] iex&gt; Descisionex.Helper . find_min_criteria ( matrix ) { [ 0 , 1 ] , 2 }","ref":"Descisionex.Helper.html#find_min_criteria/1","title":"Descisionex.Helper.find_min_criteria/1","type":"function"},{"doc":"Normalizes matrix. Examples iex&gt; matrix = [ [ 1 , 2 ] , [ 3 , 4 ] , [ 0 , 1 ] ] iex&gt; size = 3 # matrix rows iex&gt; Descisionex.Helper . normalize ( matrix , size ) [ [ 0.25 , 0.286 ] , [ 0.75 , 0.571 ] , [ 0.0 , 0.143 ] ]","ref":"Descisionex.Helper.html#normalize/2","title":"Descisionex.Helper.normalize/2","type":"function"},{"doc":"Matrix rounding to 3 numbers. Examples iex&gt; matrix = [ [ 1 / 3 , 2 / 3 ] , [ 4 / 5 , 5 / 6 ] ] iex&gt; Descisionex.Helper . round_matrix ( matrix ) [ [ 0.333 , 0.667 ] , [ 0.8 , 0.833 ] ]","ref":"Descisionex.Helper.html#round_matrix/1","title":"Descisionex.Helper.round_matrix/1","type":"function"},{"doc":"https://en.wikipedia.org/wiki/Decision-matrix_method","ref":"Descisionex.PaymentMatrix.html","title":"Descisionex.PaymentMatrix","type":"module"},{"doc":"Calculates all criteria for payment matrix. Examples iex&gt; % Descisionex.PaymentMatrix { matrix : [ [ 1 , 2 ] , [ 3 , 4 ] ] } |&gt; Descisionex.PaymentMatrix . set_variants ( [ &quot;some&quot; , &quot;variants&quot; ] ) |&gt; Descisionex.PaymentMatrix . calculate_criteria ( ) % Descisionex.PaymentMatrix { generalized_additional_value : 0.5 , generalized_criterion : %{ criterion : 1.5 , strategy_index : 0 } , hurwitz_additional_value : 0.5 , hurwitz_criterion : %{ criterion : 3.5 , strategy_index : 1 } , laplace_criterion : %{ criterion : 3.5 , strategy_index : 1 } , matrix : [ [ 1 , 2 ] , [ 3 , 4 ] ] , possible_steps : [ ] , possible_steps_num : 0 , savage_criterion : %{ criterion : 0 , strategy_index : 1 } , variants : [ &quot;some&quot; , &quot;variants&quot; ] , variants_num : 2 , wald_criterion : %{ criterion : 4 , strategy_index : 1 } }","ref":"Descisionex.PaymentMatrix.html#calculate_criteria/1","title":"Descisionex.PaymentMatrix.calculate_criteria/1","type":"function"},{"doc":"Calculates generalized criterion for payment matrix. Examples iex&gt; % Descisionex.PaymentMatrix { matrix : [ [ 1 , 2 ] , [ 3 , 4 ] ] } |&gt; Descisionex.PaymentMatrix . calculate_generalized_criterion ( ) % Descisionex.PaymentMatrix { generalized_additional_value : 0.5 , generalized_criterion : %{ criterion : 1.5 , strategy_index : 0 } , hurwitz_additional_value : 0.5 , hurwitz_criterion : %{ } , laplace_criterion : %{ } , matrix : [ [ 1 , 2 ] , [ 3 , 4 ] ] , possible_steps : [ ] , possible_steps_num : 0 , savage_criterion : %{ } , variants : [ ] , variants_num : 0 , wald_criterion : %{ } }","ref":"Descisionex.PaymentMatrix.html#calculate_generalized_criterion/1","title":"Descisionex.PaymentMatrix.calculate_generalized_criterion/1","type":"function"},{"doc":"Calculates Hurwitz criterion for payment matrix. Examples iex&gt; % Descisionex.PaymentMatrix { matrix : [ [ 1 , 2 ] , [ 3 , 4 ] ] } |&gt; Descisionex.PaymentMatrix . calculate_hurwitz_criterion ( ) % Descisionex.PaymentMatrix { generalized_additional_value : 0.5 , generalized_criterion : %{ } , hurwitz_additional_value : 0.5 , hurwitz_criterion : %{ criterion : 3.5 , strategy_index : 1 } , laplace_criterion : %{ } , matrix : [ [ 1 , 2 ] , [ 3 , 4 ] ] , possible_steps : [ ] , possible_steps_num : 0 , savage_criterion : %{ } , variants : [ ] , variants_num : 0 , wald_criterion : %{ } }","ref":"Descisionex.PaymentMatrix.html#calculate_hurwitz_criterion/1","title":"Descisionex.PaymentMatrix.calculate_hurwitz_criterion/1","type":"function"},{"doc":"Calculates Laplace criterion for payment matrix (variants must be set). Examples iex&gt; % Descisionex.PaymentMatrix { matrix : [ [ 1 , 2 ] , [ 3 , 4 ] ] } |&gt; Descisionex.PaymentMatrix . calculate_laplace_criterion ( ) ** (ArgumentError) For Laplace criterion variants must be set! iex&gt; % Descisionex.PaymentMatrix { matrix : [ [ 1 , 2 ] , [ 3 , 4 ] ] } |&gt; Descisionex.PaymentMatrix . set_variants ( [ &quot;some&quot; , &quot;variants&quot; ] ) |&gt; Descisionex.PaymentMatrix . calculate_laplace_criterion ( ) % Descisionex.PaymentMatrix { generalized_additional_value : 0.5 , generalized_criterion : %{ } , hurwitz_additional_value : 0.5 , hurwitz_criterion : %{ } , laplace_criterion : %{ criterion : 3.5 , strategy_index : 1 } , matrix : [ [ 1 , 2 ] , [ 3 , 4 ] ] , possible_steps : [ ] , possible_steps_num : 0 , savage_criterion : %{ } , variants : [ &quot;some&quot; , &quot;variants&quot; ] , variants_num : 2 , wald_criterion : %{ } }","ref":"Descisionex.PaymentMatrix.html#calculate_laplace_criterion/1","title":"Descisionex.PaymentMatrix.calculate_laplace_criterion/1","type":"function"},{"doc":"Calculates Savage criterion for payment matrix. Examples iex&gt; % Descisionex.PaymentMatrix { matrix : [ [ 1 , 2 ] , [ 3 , 4 ] ] } |&gt; Descisionex.PaymentMatrix . calculate_savage_criterion ( ) % Descisionex.PaymentMatrix { generalized_additional_value : 0.5 , generalized_criterion : %{ } , hurwitz_additional_value : 0.5 , hurwitz_criterion : %{ } , laplace_criterion : %{ } , matrix : [ [ 1 , 2 ] , [ 3 , 4 ] ] , possible_steps : [ ] , possible_steps_num : 0 , savage_criterion : %{ criterion : 0 , strategy_index : 1 } , variants : [ ] , variants_num : 0 , wald_criterion : %{ } }","ref":"Descisionex.PaymentMatrix.html#calculate_savage_criterion/1","title":"Descisionex.PaymentMatrix.calculate_savage_criterion/1","type":"function"},{"doc":"Calculates Wald criterion for payment matrix. Examples iex&gt; % Descisionex.PaymentMatrix { matrix : [ [ 1 , 2 ] , [ 3 , 4 ] ] } |&gt; Descisionex.PaymentMatrix . calculate_wald_criterion ( ) % Descisionex.PaymentMatrix { generalized_additional_value : 0.5 , generalized_criterion : %{ } , hurwitz_additional_value : 0.5 , hurwitz_criterion : %{ } , laplace_criterion : %{ } , matrix : [ [ 1 , 2 ] , [ 3 , 4 ] ] , possible_steps : [ ] , possible_steps_num : 0 , savage_criterion : %{ } , variants : [ ] , variants_num : 0 , wald_criterion : %{ criterion : 4 , strategy_index : 1 } }","ref":"Descisionex.PaymentMatrix.html#calculate_wald_criterion/1","title":"Descisionex.PaymentMatrix.calculate_wald_criterion/1","type":"function"},{"doc":"Set Generalized additional value for payment matrix (range from 0.1 to 0.9), defaults to 0.5. Examples iex&gt; % Descisionex.PaymentMatrix { } |&gt; Descisionex.PaymentMatrix . set_generalized_additional_value ( 0.3 ) % Descisionex.PaymentMatrix { generalized_additional_value : 0.3 , generalized_criterion : %{ } , hurwitz_additional_value : 0.5 , hurwitz_criterion : %{ } , laplace_criterion : %{ } , matrix : [ ] , possible_steps : [ ] , possible_steps_num : 0 , savage_criterion : %{ } , variants : [ ] , variants_num : 0 , wald_criterion : %{ } } iex&gt; % Descisionex.PaymentMatrix { } |&gt; Descisionex.PaymentMatrix . set_generalized_additional_value ( 0 ) ** (ArgumentError) Generalized additional value incorrect (number range must be from 0.1 to 0.9)","ref":"Descisionex.PaymentMatrix.html#set_generalized_additional_value/2","title":"Descisionex.PaymentMatrix.set_generalized_additional_value/2","type":"function"},{"doc":"Set Hurwitz additional value for payment matrix (range from 0.1 to 0.9), defaults to 0.5. Examples iex&gt; % Descisionex.PaymentMatrix { } |&gt; Descisionex.PaymentMatrix . set_hurwitz_additional_value ( 0.3 ) % Descisionex.PaymentMatrix { generalized_additional_value : 0.5 , generalized_criterion : %{ } , hurwitz_additional_value : 0.3 , hurwitz_criterion : %{ } , laplace_criterion : %{ } , matrix : [ ] , possible_steps : [ ] , possible_steps_num : 0 , savage_criterion : %{ } , variants : [ ] , variants_num : 0 , wald_criterion : %{ } } iex&gt; % Descisionex.PaymentMatrix { } |&gt; Descisionex.PaymentMatrix . set_hurwitz_additional_value ( 0 ) ** (ArgumentError) Hurwitz additional value incorrect (number range must be from 0.1 to 0.9)","ref":"Descisionex.PaymentMatrix.html#set_hurwitz_additional_value/2","title":"Descisionex.PaymentMatrix.set_hurwitz_additional_value/2","type":"function"},{"doc":"Set steps for payment matrix. Examples iex&gt; % Descisionex.PaymentMatrix { } |&gt; Descisionex.PaymentMatrix . set_steps ( [ &quot;some&quot; , &quot;steps&quot; ] ) % Descisionex.PaymentMatrix { generalized_additional_value : 0.5 , generalized_criterion : %{ } , hurwitz_additional_value : 0.5 , hurwitz_criterion : %{ } , laplace_criterion : %{ } , matrix : [ ] , possible_steps : [ &quot;some&quot; , &quot;steps&quot; ] , possible_steps_num : 2 , savage_criterion : %{ } , variants : [ ] , variants_num : 0 , wald_criterion : %{ } }","ref":"Descisionex.PaymentMatrix.html#set_steps/2","title":"Descisionex.PaymentMatrix.set_steps/2","type":"function"},{"doc":"Set variants for payment matrix. Examples iex&gt; % Descisionex.PaymentMatrix { } |&gt; Descisionex.PaymentMatrix . set_variants ( [ &quot;some&quot; , &quot;variants&quot; ] ) % Descisionex.PaymentMatrix { generalized_additional_value : 0.5 , generalized_criterion : %{ } , hurwitz_additional_value : 0.5 , hurwitz_criterion : %{ } , laplace_criterion : %{ } , matrix : [ ] , possible_steps : [ ] , possible_steps_num : 0 , savage_criterion : %{ } , variants : [ &quot;some&quot; , &quot;variants&quot; ] , variants_num : 2 , wald_criterion : %{ } }","ref":"Descisionex.PaymentMatrix.html#set_variants/2","title":"Descisionex.PaymentMatrix.set_variants/2","type":"function"}]